import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.component.em.em_stock_info_api as em_stock_info_api
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.api.ths.company.company_product_area_industry_index_query as company_product_area_industry_index_query
from loguru import logger
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.utils.data_frame_util as data_frame_util
import pandas as pd
from datetime import datetime

mongodb_util = MongodbUtil('27017')


def sync_company_product_area_industry_task(symbol):
    now_date = datetime.now()
    now_year = now_date.year
    now_month = now_date.month

    if now_month in [1, 2, 3, 4]:
        period_time_year = str(now_year - 1) + "-12-31"
        sync_company_product_area_industry(symbol, period_time_year)

    if now_month in [4, 5, 6]:
        period_time_one = str(now_year) + "-03-31"
        sync_company_product_area_industry(symbol, period_time_one)

    elif now_month in [7, 8, 9]:
        period_time_two = str(now_year) + "-06-30"
        sync_company_product_area_industry(symbol, period_time_two)

    elif now_month in [10, 11, 12]:
        period_time_three = str(now_year) + "-09-30"
        sync_company_product_area_industry(symbol, period_time_three)


def sync_company_product_area_industry(symbol, date):
    real_time_quotes_all_stocks = em_stock_info_api.get_a_stock_info()
    real_time_quotes_all_stocks = common_service_fun_api.classify_symbol(real_time_quotes_all_stocks)
    if symbol is not None:
        real_time_quotes_all_stocks = real_time_quotes_all_stocks.loc[real_time_quotes_all_stocks['symbol'] == symbol]
    for stock_one in real_time_quotes_all_stocks.itertuples():
        try:
            symbol = stock_one.symbol

            if date is not None:
                query_exist = {"symbol": symbol, "time": date}
                if mongodb_util.exist_data_query(db_name_constant.COMPANY_BUSINESS_INFO, query_exist):
                    continue

            classification = stock_one.classification
            if classification in ['H', 'K']:
                market = '17'
            elif classification in ['S', 'C']:
                market = '33'
            elif classification in ['X']:
                market = '151'

            company_product_area_industry_list = company_product_area_industry_index_query.company_product_area_industry(
                symbol, market, date)
            for company_one in company_product_area_industry_list:
                try:
                    analysis_type = company_one['analysis_type']
                    time_operate_index_item_list = company_one['time_operate_index_item_list']
                    time_operate_index_item_df = pd.DataFrame(time_operate_index_item_list)
                    if data_frame_util.is_empty(time_operate_index_item_df):
                        continue
                    time_operate_index_item_df['symbol'] = symbol
                    time_operate_index_item_df['analysis_type'] = analysis_type

                    time_operate_index_item_df['_id'] = symbol + '_' + time_operate_index_item_df[
                        'time'] + '_' + analysis_type
                    handle_industry_area_product(time_operate_index_item_df, symbol)
                except BaseException as e:
                    logger.error("同步经营数据异常:{},{}", symbol, e)

            logger.info("同步经营数据完成:{}", stock_one.symbol)
        except BaseException as e:
            logger.error("同步经营数据:{},{}", stock_one.symbol, e)


def handle_industry_area_product(time_operate_index_item_df, symbol):
    if data_frame_util.is_empty(time_operate_index_item_df):
        return None

    for business_one in time_operate_index_item_df.itertuples():
        time = business_one.time
        analysis_type = business_one.analysis_type

        product_index_item_list = business_one.product_index_item_list
        for product_one in product_index_item_list:
            try:
                # 初始化数据
                income_amount = 0
                income_percent = 0
                cost_amount = 0
                cost_percent = 0
                gross_profit_amount = 0
                gross_profit_percent = 0
                gross_profit_rate_amount = 0
                gross_profit_rate_percent = 0

                product_name = product_one['product_name']
                index_analysis_list = product_one['index_analysis_list']
                for index_one in index_analysis_list:
                    try:
                        index_id = index_one['index_id']
                        if index_id == 'income':
                            income_amount = index_one['index_value']
                            income_percent = index_one['account']
                        elif index_id == 'cost':
                            cost_amount = index_one['index_value']
                            cost_percent = index_one['account']
                        elif index_id == 'gross_profit':
                            gross_profit_amount = index_one['index_value']
                            gross_profit_percent = index_one['account']

                        elif index_id == 'gross_profit_rate':
                            gross_profit_rate_amount = index_one['index_value']
                            gross_profit_rate_percent = index_one['account']
                    except BaseException as e:
                        logger.error("同步经营数据异常:{},{}", symbol, e)

                id_key = symbol + '_' + time + '_' + analysis_type + '_' + product_name
                result_dict = {
                    '_id': id_key,
                    'symbol': symbol,
                    'time': time,
                    'analysis_type': analysis_type,
                    'product_name': product_name,

                    'income_amount': income_amount,
                    'income_percent': income_percent,

                    'cost_amount': cost_amount,
                    'cost_percent': cost_percent,

                    'gross_profit_amount': gross_profit_amount,
                    'gross_profit_percent': gross_profit_percent,

                    'gross_profit_rate_amount': gross_profit_rate_amount,
                    'gross_profit_rate_percent': gross_profit_rate_percent,
                }
                result_dict_df = pd.DataFrame(result_dict, index=[1])
                mongodb_util.save_mongo(result_dict_df, db_name_constant.COMPANY_BUSINESS_INFO)
            except BaseException as e:
                logger.error("同步经营数据异常:{},{}", symbol, e)


if __name__ == '__main__':
    sync_company_product_area_industry('300211', '2025-09-30')
    # sync_company_product_area_industry('002323')
    # sync_company_product_area_industry('300901')
    # sync_company_product_area_industry('603225')
    # sync_company_product_area_industry('688039')
    # sync_company_product_area_industry('600849')
    # sync_company_product_area_industry('000508')
    # sync_company_product_area_industry('810011')

    sync_company_product_area_industry(None, None)



import sys
import os

import pandas as pd

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.akshare.k_line_api as k_line_api
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.api.xueqiu.xue_qiu_k_line_api as xue_qiu_k_line_api
import mns_common.component.cookie.cookie_info_service as cookie_info_service
import mns_common.component.common_service_fun_api as common_service_fun_api
from datetime import datetime, timedelta
import mns_common.api.msg.push_msg_api as push_msg_api
import numpy as np
import mns_common.utils.data_frame_util as data_frame_util
from loguru import logger
import threading

# source_type = 'xue_qiu'
source_type = 'xue_qiu'
error_no = 1


# 自定义报警处理函数
def custom_alert(current: int, threshold: int):
    push_msg_api.push_msg_to_wechat('获取k线数据异常', "当前次数:" + str(current) + "阈值:" + str(threshold))


# 定义一个带超时的函数调用
def call_with_timeout(func, *args, timeout=10, **kwargs):
    # 用于存储函数执行结果
    result = None
    exception = None

    # 定义一个线程目标函数
    def target():
        nonlocal result, exception
        try:
            result = func(*args, **kwargs)
        except Exception as e:
            exception = e

    # 创建线程并启动
    thread = threading.Thread(target=target)
    thread.start()

    # 等待线程完成，最多等待 timeout 秒
    thread.join(timeout)

    # 如果线程仍然存活，说明函数超时了
    if thread.is_alive():
        raise TimeoutError(f"Function exceeded timeout of {timeout} seconds")

    # 如果函数抛出了异常，重新抛出
    if exception is not None:
        raise exception
    return result


def get_k_line_common_adapter(symbol, period, hq, end_date):
    global error_no
    df = pd.DataFrame()
    try:
        if source_type == 'em':

            df = call_with_timeout(get_em_k_line_api,
                                   symbol,
                                   period,
                                   hq,
                                   end_date,
                                   timeout=10)
        elif source_type == 'xue_qiu':
            df = call_with_timeout(get_xueqiu_k_line_api,
                                   symbol,
                                   period,
                                   hq,
                                   end_date,
                                   timeout=10)

        if data_frame_util.is_empty(df):
            error_no = error_no + 1
    except BaseException as e:
        logger.error("获取k线异常:{}", e)
        error_no = error_no + 1
    if error_no == 1000:
        push_msg_api.push_msg_to_wechat('获取k线数据异常', "当前次数:" + str(error_no))
    return df


# 应用带参数的装饰器
# @exception_counter(
#     threshold=1500,
#     alert_handler=custom_alert,
#     auto_reset=False
# )
def get_em_k_line_api(symbol, period, hq, end_date):
    # 检查symbol是否以'6'开头
    if symbol.startswith('6'):
        symbol_a = '1.' + symbol
    else:
        symbol_a = '0.' + symbol
    stock_hfq_df = k_line_api.stock_zh_a_hist(symbol=symbol_a,
                                              period=period,
                                              start_date=date_handle_util.no_slash_date('1990-12-19'),
                                              end_date=date_handle_util.no_slash_date(end_date),
                                              adjust=hq)

    stock_hfq_df.rename(columns={"日期": "date", "开盘": "open",
                                 "收盘": "close", "最高": "high",
                                 "最低": "low", "成交量": "volume",
                                 "成交额": "amount", "振幅": "pct_chg",
                                 "涨跌幅": "chg", "涨跌额": "change",
                                 "换手率": "exchange"}, inplace=True)
    stock_hfq_df['symbol'] = symbol
    stock_hfq_df['_id'] = symbol + '-' + stock_hfq_df['date']
    return stock_hfq_df


# period : year  quarter  month  week  day
# hq: qfq:before ,hfq:after, bfq:normal

def get_xueqiu_k_line_api(symbol, period, hq, end_date):
    if hq == 'qfq':
        adjust = 'before'
    elif hq == 'hfq':
        adjust = 'after'
    else:
        adjust = 'normal'

    period_time = 'day'
    if period == 'daily':
        period_time = 'day'
    elif period == 'weekly':
        period_time = 'week'
    elif period == 'monthly':
        period_time = 'month'

    cookie = cookie_info_service.get_xue_qiu_cookie()
    symbol_pre_fix = common_service_fun_api.add_pre_prefix_one(symbol)
    dt = datetime.strptime(end_date, '%Y-%m-%d')
    dt += timedelta(days=1)
    timestamp = str(int(dt.timestamp() * 1000))  # 转换为毫秒
    stock_k_line_df = xue_qiu_k_line_api.get_xue_qiu_k_line(symbol_pre_fix, period_time,
                                                            cookie, timestamp, adjust)

    stock_k_line_df['pct_chg'] = round(abs(stock_k_line_df['high'] - stock_k_line_df['low'] / stock_k_line_df['high']),
                                       2)
    stock_k_line_df.rename(columns={"chg": "change",
                                    "percent": "chg",
                                    "str_day": "date",
                                    "market_capital": "flow_mv",
                                    "turnoverrate": "exchange"}, inplace=True)
    stock_k_line_df = stock_k_line_df[[
        "date",
        "open",
        "close",
        "high",
        "low",
        "volume",
        "amount",
        "pct_chg",
        "chg",
        "change",
        "exchange"
    ]]
    stock_k_line_df['symbol'] = symbol
    stock_k_line_df['date'] = stock_k_line_df['date'].str.replace('-', '')
    stock_k_line_df['_id'] = symbol + '-' + stock_k_line_df['date']
    stock_k_line_df['last_price'] = round(((stock_k_line_df['close']) / (1 + stock_k_line_df['chg'] / 100)), 2)
    stock_k_line_df['max_chg'] = round(
        ((stock_k_line_df['high'] - stock_k_line_df['last_price']) / stock_k_line_df['last_price']) * 100, 2)
    stock_k_line_df['amount_level'] = round((stock_k_line_df['amount'] / common_service_fun_api.HUNDRED_MILLION), 2)
    stock_k_line_df['flow_mv'] = round(stock_k_line_df['amount'] * 100 / stock_k_line_df['exchange'], 2)
    stock_k_line_df['flow_mv_sp'] = round(stock_k_line_df['flow_mv'] / common_service_fun_api.HUNDRED_MILLION, 2)

    stock_k_line_df.replace([np.inf, -np.inf], 0, inplace=True)
    stock_k_line_df.fillna(0, inplace=True)
    stock_k_line_df['date'] = stock_k_line_df['date'].astype(str).str[:8]
    return stock_k_line_df


if __name__ == '__main__':
    while True:
        test_df = get_k_line_common_adapter('000001', 'day', 'qfq', '2025-05-25')
        print(test_df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.extra_income_db_name as extra_income_db_name
import mns_scheduler.finance.xue_qiu.down_load_xueqiu_report_api as down_load_xueqiu_report_api
import mns_common.component.common_service_fun_api as common_service_fun_api
import pandas as pd
from loguru import logger
import time
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.component.cookie.cookie_info_service as cookie_info_service
from datetime import datetime
import mns_common.component.em.em_stock_info_api as em_stock_info_api

mongodb_util_27017 = MongodbUtil('27017')


# report_type income 利润表
# cash_flow 现金流量
# balance 资产负债
# 同步所有股票 报表
def sync_all_stocks_report():
    em_a_stock_info_df = em_stock_info_api.get_a_stock_info()
    em_a_stock_info_df = common_service_fun_api.add_pre_prefix(em_a_stock_info_df)
    # 或等效写法 df['A'].str[0:6]

    fail_list = []

    xue_qiu_cookie = cookie_info_service.get_xue_qiu_cookie()
    report_type_list = ['income', 'balance', 'cash_flow']
    for stock_one in em_a_stock_info_df.itertuples():
        fail_list = save_one_symbol_data(stock_one, report_type_list, xue_qiu_cookie, True, fail_list, '', False)

    handle_number = 0
    # 处理失败的
    while len(fail_list) > 0:
        fail_df = em_a_stock_info_df.loc[em_a_stock_info_df['symbol'].isin(fail_list)]
        for fail_one in fail_df.itertuples():
            fail_list = save_one_symbol_data(fail_one, report_type_list, xue_qiu_cookie, True, fail_list, '', False)
        handle_number = handle_number + 1
        if handle_number > 10:
            break


def save_one_symbol_data(stock_one, report_type_list, xue_qiu_cookie, save_tag, fail_list, report_name, check_exist):
    try:
        symbol_prefix = stock_one.symbol_prefix
        name = stock_one.name
        symbol = stock_one.symbol
        for report_type in report_type_list:
            if report_type == 'income':
                col_name = extra_income_db_name.XUE_QIU_LRB_INCOME
            elif report_type == 'balance':
                col_name = extra_income_db_name.XUE_QIU_ASSET_DEBT
            elif report_type == 'cash_flow':
                col_name = extra_income_db_name.XUE_QIU_CASH_FLOW
            if check_exist:
                query_exist = {'symbol': symbol, 'report_name': report_name}
                # 存在数据 不在同步
                if mongodb_util_27017.exist_data_query(col_name, query_exist):
                    continue

            index_create = [('symbol', 1), ('report_date', 1)]
            mongodb_util_27017.create_index(col_name, index_create)

            index_create_01 = [('symbol', 1), ('sync_time', 1)]
            mongodb_util_27017.create_index(col_name, index_create_01)

            if check_exist:
                # 季度同步只同步一条数据
                result_df = down_load_xueqiu_report_api.get_xue_qiu_report(symbol_prefix, report_type, xue_qiu_cookie,
                                                                           1,
                                                                           'all')
            else:
                result_df = down_load_xueqiu_report_api.get_xue_qiu_report(symbol_prefix, report_type, xue_qiu_cookie,
                                                                           200,
                                                                           'all')

            now_date = datetime.now()
            sync_time = now_date.strftime('%Y-%m-%d %H:%M:%S')

            if data_frame_util.is_empty(result_df):
                logger.error("财务信息为空,代码:{}:{}", symbol, name)
                continue
            else:
                # 季度同步check
                if check_exist:
                    result_df = result_df.loc[result_df['report_name'] == report_name]
                    if data_frame_util.is_empty(result_df):
                        continue

            result_df['sync_time'] = sync_time
            time.sleep(0.5)
            # 1. 将毫秒时间戳转为 datetime
            result_df['report_date'] = pd.to_datetime(result_df['report_date'], unit='ms')

            # 2. 格式化为 '%Y-%m-%d' 字符串
            result_df['report_date'] = result_df['report_date'].dt.strftime('%Y-%m-%d')

            result_df['_id'] = symbol + '_' + result_df['report_date']
            result_df['symbol'] = symbol

            # 1. 将毫秒时间戳转为 datetime
            result_df['ctime'] = pd.to_datetime(result_df['ctime'], unit='ms')

            # 2. 格式化为 '%Y-%m-%d' 字符串
            result_df['ctime'] = result_df['ctime'].dt.strftime('%Y-%m-%d')
            result_df.loc[result_df['report_name'].str.contains('年报'), 'period'] = 4
            result_df.loc[result_df['report_name'].str.contains('一季报'), 'period'] = 1
            result_df.loc[result_df['report_name'].str.contains('中报'), 'period'] = 2
            result_df.loc[result_df['report_name'].str.contains('三季报'), 'period'] = 3
            result_df['year'] = result_df['report_name'].str[:4]
            if save_tag:
                mongodb_util_27017.save_mongo(result_df, col_name)
            else:
                mongodb_util_27017.insert_mongo(result_df, col_name)

            if symbol in fail_list:
                fail_list.remove(symbol)
        logger.info("同步完成数据:{}:{}", symbol, name)
    except BaseException as e:
        logger.error("同步错误:{},异常信息:{}", symbol, e)
        fail_list.append(symbol)
    return fail_list


def sync_xue_qiu_very_period_report(report_name, symbol):
    em_a_stock_info_df = em_stock_info_api.get_a_stock_info()
    if symbol is not None:
        em_a_stock_info_df = em_a_stock_info_df.loc[em_a_stock_info_df['symbol'] == symbol]
    em_a_stock_info_df = common_service_fun_api.add_pre_prefix(em_a_stock_info_df)
    # 或等效写法 df['A'].str[0:6]

    fail_list = []

    xue_qiu_cookie = cookie_info_service.get_xue_qiu_cookie()
    report_type_list = ['income', 'balance', 'cash_flow']
    for stock_one in em_a_stock_info_df.itertuples():
        fail_list = save_one_symbol_data(stock_one, report_type_list, xue_qiu_cookie, False, fail_list, report_name,
                                         True)

    handle_number = 0
    # 处理失败的
    while len(fail_list) > 0:
        fail_df = em_a_stock_info_df.loc[em_a_stock_info_df['symbol'].isin(fail_list)]
        for fail_one in fail_df.itertuples():
            fail_list = save_one_symbol_data(fail_one, report_type_list, xue_qiu_cookie, False, fail_list, report_name,
                                             True)
        handle_number = handle_number + 1
        if handle_number > 10:
            break


if __name__ == '__main__':
    sync_all_stocks_report()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
import akshare as ak
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
import mns_common.constant.db_name_constant as db_name_constant


# 同步退市股票
def sync_de_list_stock():
    sh_de_list_df = ak.stock_info_sh_delist(symbol="全部")
    sh_de_list_df = sh_de_list_df.rename(columns={"公司代码": "symbol",
                                                  "公司简称": "name",
                                                  "上市日期": "list_date",
                                                  "暂停上市日期": "de_list_date"
                                                  })

    sz_de_list_df = ak.stock_info_sz_delist(symbol="终止上市公司")
    sz_de_list_df = sz_de_list_df.rename(columns={"证券代码": "symbol",
                                                  "证券简称": "name",
                                                  "上市日期": "list_date",
                                                  "终止上市日期": "de_list_date"
                                                  })
    all_de_list_df = pd.concat([sz_de_list_df, sh_de_list_df])
    all_de_list_df['_id'] = all_de_list_df['symbol']
    all_de_list_df['list_date'] = all_de_list_df['list_date'].astype(str)
    all_de_list_df['de_list_date'] = all_de_list_df['de_list_date'].astype(str)
    mongodb_util.save_mongo(all_de_list_df, db_name_constant.DE_LIST_STOCK)
    remove_black_list(all_de_list_df)


# 移除黑名单
def remove_black_list(all_de_list_df):
    symbol_list = list(all_de_list_df['symbol'])
    remove_query = {'symbol': {"$in": symbol_list}}
    mongodb_util.remove_data(remove_query, db_name_constant.SELF_BLACK_STOCK)


if __name__ == '__main__':
    sync_de_list_stock()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.ths.company.ths_company_info_api as ths_company_info_api
import mns_common.component.cookie.cookie_info_service as cookie_info_service
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
from datetime import datetime
from mns_common.utils.async_fun import async_fun
from loguru import logger

mongodb_util = MongodbUtil('27017')


# 同步公司控股子公司信息
@async_fun
def sync_company_hold_info(symbol):
    try:
        ths_cookie = cookie_info_service.get_ths_cookie()
        company_hold_info_df = ths_company_info_api.get_company_hold_info(symbol, ths_cookie)

        now_date = datetime.now()
        sync_str_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
        if data_frame_util.is_not_empty(company_hold_info_df):
            query = {'symbol': symbol}
            result = mongodb_util.remove_data(query, db_name_constant.COMPANY_HOLDING_INFO)
            if result.acknowledged:
                company_hold_info_df['sync_str_date'] = sync_str_date
                mongodb_util.insert_mongo(company_hold_info_df, db_name_constant.COMPANY_HOLDING_INFO)
    except BaseException as e:
        logger.error("同步公司控股子公司信息:{},{}", symbol, e)


if __name__ == '__main__':
    sync_company_hold_info('300085')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.utils.data_frame_util as data_frame_util
from mns_scheduler.db.script.sync.remote_mongo_util import RemoteMongodbUtil
from mns_scheduler.db.script.sync.local_mongo_util import LocalMongodbUtil
from loguru import logger
import numpy as np

remote_mongodb_util = RemoteMongodbUtil('27017')
local_mongodb_util = LocalMongodbUtil('27017')

col_list = [
    'em_a_stock_info',
    'em_etf_info',
    'em_kzz_info',
    'em_hk_stock_info',
    'company_info',
    'company_remark_info',
    'company_holding_info',
    'industry_concept_remark',
    'trade_date_list',
    'de_list_stock',
    'kpl_best_choose_index',
    'kpl_best_choose_index_detail',
    'realtime_quotes_now_zt_new_kc_open',
    'industry_concept_remark',
    'self_black_stock',
    'self_choose_plate',
    'self_choose_stock',
    'stock_account_info',
    'ths_concept_list',
    'stock_zt_pool_five',
    'ths_stock_concept_detail',
    'stock_high_chg_pool',
    'today_new_concept_list',
    'ths_stock_concept_detail_app'
]


def remote_data():
    for col in col_list:
        try:
            col_df = remote_mongodb_util.find_all_data(col)
            if data_frame_util.is_not_empty(col_df):
                result = local_mongodb_util.remove_all_data(col)
                if result.acknowledged:
                    col_df.replace([np.inf, -np.inf], 0, inplace=True)

                    local_mongodb_util.save_mongo(col_df, col)

                logger.info("同步集合完成:{}", col)
        except BaseException as e:
            logger.error("同步失败:{},{}", e, col)


def sync_zt_data(str_day):
    col = 'stock_zt_pool'
    try:
        query = {'str_day': str_day}
        col_df = remote_mongodb_util.find_query_data(col, query)
        if data_frame_util.is_not_empty(col_df):
            col_df.replace([np.inf, -np.inf], 0, inplace=True)
            local_mongodb_util.save_mongo(col_df, col)

        logger.info("同步集合完成:{}", col)
    except BaseException as e:
        logger.error("同步失败:{},{}", e, col)


def sync_open_data():
    query = {"$and": [{'trade_date': {"$gte": "2025-03-21"}}, {'trade_date': {"$lte": "2025-04-02"}}]}
    trade_date_list_df = remote_mongodb_util.find_query_data('trade_date_list', query)
    trade_date_list_df = trade_date_list_df.sort_values(by=['trade_date'], ascending=False)
    for trade_date_one in trade_date_list_df.itertuples():
        try:
            trade_date = trade_date_one.trade_date
            query_01 = {"str_day": trade_date}
            realtime_quotes_now_open_df = remote_mongodb_util.find_query_data('realtime_quotes_now_open', query_01)
            if 'ths_concept_list' in realtime_quotes_now_open_df.columns:
                del realtime_quotes_now_open_df['ths_concept_list']
            local_mongodb_util.insert_mongo(realtime_quotes_now_open_df, 'realtime_quotes_now_open')
            logger.info("同步到:{}", trade_date)
        except BaseException as e:
            logger.error("同步异常:{}", e)
    return trade_date_list_df


if __name__ == '__main__':
    sync_zt_data('2025-09-17')
    # sync_zt_data('2025-09-02')
    remote_data()
    # sync_zt_data('2025-08-26')
    # sync_zt_data('2025-08-25')
    # sync_zt_data('2025-08-26')
    # remote_data()
    # sync_zt_data('2025-07-23')
    # sync_zt_data('2025-07-24')
    # sync_zt_data('2025-07-25')
    # sync_open_data()
    # remote_data()
